<p align="center">
<img width=75% src="/gridstatus-header.png" alt="gridstatus logo" />
</p>
<p align="center">
  <a href="https://github.com/gridstatus/gridstatusio/actions/workflows/tests.yaml" target="_blank">
        <img src="https://github.com/gridstatus/gridstatusio/actions/workflows/tests.yaml/badge.svg" alt="Tests" />
    </a>
   <a href="https://badge.fury.io/py/gridstatusio" target="_blank">
        <img src="https://badge.fury.io/py/gridstatusio.svg?maxAge=2592000" alt="PyPI version">
    </a>
</p>

# GridStatus.io Hosted API

Python client for accessing the [GridStatus.io Hosted API](https://www.gridstatusio.io/api).

## Installation

gridstatusio supports python 3.8+. Install with pip:

```bash
pip install gridstatusio
```

Upgrade using the following command

```
python -m pip install --upgrade gridstatusio
```

## Getting Started

Check out this example notebook: [Getting Started](/Examples/Getting%20Started.ipynb)

Other Examples:

- [Stacked Net Load Visualization](/Examples/Stacked%20Net%20Load%20Visualization.ipynb)
- [CAISO April Net Load Analysis](/Examples/CAISO%20April%20Net%20Load.ipynb)
- [Resample Data to Different Frequencies](/Examples/Resample%20Data.ipynb)

## Open Source

If you prefer to use an open source library that fetches data directly from the source, you can check out the [github repo](https://github.com/kmax12/gridstatus). For more information on Hosted API vs Open Source API, please see this [guide](https://api.gridstatus.io/docs#section/Getting-Started/Open-Source)

## Get Help

We'd love to answer any usage or data access questions! Please let us know by emailing us at contact@gridstatus.io
